==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mailadresse");
define("_RE","Sv");
define("_SUBJECT","Emne");
define("_PRIVATEMESSAGES","Dine private beskeder");
define("_CHECKALL","Marker alle");
define("_FROM","Fra");
define("_DATE","Dato");
define("_DONTHAVEMESSAGES","Du har ingen beskeder");
define("_NOTREAD","Ikke lst");
define("_MSGSTATUS","Beskedstatus");
define("_PRIVATEMESSAGE","Private beskeder");
define("_INDEX","Indeks");
define("_SENT","Sendt");
define("_PREVIOUSMESSAGE","Forrige besked");
define("_NEXTMESSAGE","Nste besked");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","Om at poste");
define("_ALLREGCANPOST","Alle registrede brugere kan sende private bekseder");
define("_TO","Til");
define("_MESSAGEICON","Beskedikon");
define("_MESSAGE","Besked");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","skrevet");
define("_OPTIONS","Valg");
define("_HTMLDISSABLE","Deaktiver HTML i denne besked");
define("_BBCODEDISSABLE","Deaktiver <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> i denne besked");
define("_SMILEDISSABLE","Deaktiver <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> i denne besked");
define("_CANCELREPLY","Fortryd svar");
define("_CANCELSEND","Fortryd send");
define("_CLEAR","Ryd");
define("_SUBMIT","Send");
define("_USERNOTINDB","Den valgte bruger eksisterer ikke i vores database.");
define("_CHECKNAMEANDTRY","Kontroller navnet og prv igen.");
define("_MSGPOSTED","Din besked er sendt.");
define("_RETURNTOPMSG","Klik her for at genindlse dine private beskeder.");
define("_MSGDELETED","Dine beskeder er blevet slettet.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mailadresse");
define("_RE","Sv");
define("_SUBJECT","Emne");
define("_PRIVATEMESSAGES","Dine private beskeder");
define("_CHECKALL","Marker alle");
define("_FROM","Fra");
define("_DATE","Dato");
define("_DONTHAVEMESSAGES","Du har ingen beskeder");
define("_NOTREAD","Ikke lst");
define("_MSGSTATUS","Beskedstatus");
define("_PRIVATEMESSAGE","Private beskeder");
define("_INDEX","Indeks");
define("_SENT","Sendt");
define("_PREVIOUSMESSAGE","Forrige besked");
define("_NEXTMESSAGE","Nste besked");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","Om at poste");
define("_ALLREGCANPOST","Alle registrede brugere kan sende private bekseder");
define("_TO","Til");
define("_MESSAGEICON","Beskedikon");
define("_MESSAGE","Besked");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","skrevet");
define("_OPTIONS","Valg");
define("_HTMLDISSABLE","Deaktiver HTML i denne besked");
define("_BBCODEDISSABLE","Deaktiver <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> i denne besked");
define("_SMILEDISSABLE","Deaktiver <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> i denne besked");
define("_CANCELREPLY","Fortryd svar");
define("_CANCELSEND","Fortryd send");
define("_CLEAR","Ryd");
define("_SUBMIT","Send");
define("_USERNOTINDB","Den valgte bruger eksisterer ikke i vores database.");
define("_CHECKNAMEANDTRY","Kontroller navnet og prv igen.");
define("_MSGPOSTED","Din besked er sendt.");
define("_RETURNTOPMSG","Klik her for at genindlse dine private beskeder.");
define("_MSGDELETED","Dine beskeder er blevet slettet.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
